@@ -12,6 +12,14 @@ class FileExecutor(ExecutorBase):
         execute_function: callable = execute_in_subprocess,
         cores_per_worker: int = 1,
     ):
+        """
+        Initialize the FileExecutor.
+
+        Args:
+            cache_directory (str, optional): The directory to store cache files. Defaults to "cache".
+            execute_function (callable, optional): The function to execute tasks. Defaults to execute_in_subprocess.
+            cores_per_worker (int, optional): The number of CPU cores per worker. Defaults to 1.
+        """
         super().__init__()
         cache_directory_path = os.path.abspath(cache_directory)
         os.makedirs(cache_directory_path, exist_ok=True)
